/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef PAIRALIGNMENTSTRINGS_H
#define PAIRALIGNMENTSTRINGS_H

#include <U2Core/LRegion.h>

namespace U2 {

class PairAlignSequences {
public:
    PairAlignSequences();
    void setValues(int _score, LRegion const & _intervalSeq1);
    
    LRegion intervalSeq1;    
    int score;

    bool isAminoTranslated;
    bool isDNAComplemented;

    static const char UP = 'u';
    static const char LEFT = 'l';
    static const char DIAG = 'd';
    static const char GAP_CHARACTER = '_';
};

}//namespace

#endif
